@@ -2,7 +2,6 @@ use std::convert::{TryFrom, TryInto};
 use std::{fmt, ops};
 
 use num_traits::Signed;
-use serde::{Deserialize, Serialize};
 
 use super::errors::*;
 use super::traits::*;
@@ -11,6 +10,7 @@ use num_bigint::BigInt as BN;
 use num_bigint::Sign;
 
 mod primes;
+mod ring_algorithms;
 
 /// Big integer
 ///
@@ -18,8 +18,7 @@ mod primes;
 /// very limited API that allows easily switching between implementations.
 ///
 /// Set of traits implemented on BigInt remains the same regardless of underlying implementation.
-#[derive(PartialOrd, PartialEq, Ord, Eq, Clone, Serialize, Deserialize)]
-#[serde(transparent)]
+#[derive(PartialOrd, PartialEq, Ord, Eq, Clone)]
 pub struct BigInt {
     num: BN,
 }
@@ -99,6 +98,12 @@ impl num_traits::Num for BigInt {
 
 crate::__bigint_impl_from! { u32, i32, u64 }
 
+impl From<u16> for BigInt {
+    fn from(n: u16) -> Self {
+        BigInt::from(u64::from(n))
+    }
+}
+
 impl BasicOps for BigInt {
     fn pow(&self, exponent: u32) -> Self {
         self.num.pow(exponent).wrap()
@@ -165,7 +170,7 @@ impl Modulo for BigInt {
     }
 
     fn mod_inv(a: &Self, modulus: &Self) -> Option<Self> {
-        ring_algorithm::modulo_inverse(a.clone(), modulus.clone()).map(|inv| inv.modulus(modulus))
+        ring_algorithms::modulo_inverse(a, modulus).map(|inv| inv.modulus(modulus))
     }
 
     fn modulus(&self, modulus: &Self) -> Self {
@@ -210,7 +215,7 @@ impl NumberTests for BigInt {
 
 impl EGCD for BigInt {
     fn egcd(a: &Self, b: &Self) -> (Self, Self, Self) {
-        ring_algorithm::normalized_extended_euclidian_algorithm(a.clone(), b.clone())
+        ring_algorithms::normalized_extended_euclidian_algorithm(a, b)
     }
 }
 
@@ -371,19 +376,6 @@ impl num_traits::One for BigInt {
     }
 }
 
-impl ring_algorithm::RingNormalize for BigInt {
-    fn leading_unit(&self) -> Self {
-        match self.num.sign() {
-            Sign::Minus => -BigInt::one(),
-            _ => BigInt::one(),
-        }
-    }
-
-    fn normalize_mut(&mut self) {
-        self.num = self.num.abs();
-    }
-}
-
 macro_rules! impl_try_from {
     ($($primitive:ty),*$(,)?) => {
         $(
