@@ -1,6 +1,6 @@
 use std::fmt;
 
-use serde::de::Visitor;
+use serde::de::{SeqAccess, Visitor};
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 
 use super::traits::Converter;
@@ -36,6 +36,17 @@ impl<'de> Deserialize<'de> for BigInt {
             {
                 Ok(BigInt::from_bytes(v))
             }
+
+            fn visit_seq<A>(self, mut seq: A) -> Result<Self::Value, A::Error>
+            where
+                A: SeqAccess<'de>,
+            {
+                let mut bytes = vec![];
+                while let Some(byte) = seq.next_element::<u8>()? {
+                    bytes.push(byte)
+                }
+                Ok(BigInt::from_bytes(&bytes))
+            }
         }
 
         deserializer.deserialize_bytes(BigintVisitor)
